;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "ox-json" "20250825.125"
  "JSON export backend for Org mode."
  '((emacs "26.1")
    (org   "9")
    (s     "1.12"))
  :url "https://github.com/jlumpe/ox-json"
  :commit "0f7c63b9bbbf6c8b2547e46adc7f34289869105f"
  :revdesc "0f7c63b9bbbf"
  :keywords '("outlines")
  :authors '(("Jared Lumpe" . "jared@jaredlumpe.com"))
  :maintainers '(("Jared Lumpe" . "jared@jaredlumpe.com")))
